summaryrefslogtreecommitdiff
diff options
context:
space:
mode:
-rw-r--r--AUTHORS1
-rw-r--r--CHANGELOG8
-rw-r--r--lib/highline.rb9
3 files changed, 16 insertions, 2 deletions
diff --git a/AUTHORS b/AUTHORS
index 18ec1e9..b53016f 100644
--- a/AUTHORS
+++ b/AUTHORS
@@ -1,2 +1,3 @@
James Edward Gray II:: {james@grayproductions.net}[mailto:james@grayproductions.net]
Gregory Brown:: {gregory.t.brown@gmail.com}[mailto:gregory.t.brown@gmail.com]
+Richard LeBer:: {richard.leber@gmail.com}[mailto:richard.leber@gmail.com] \ No newline at end of file
diff --git a/CHANGELOG b/CHANGELOG
index 6d09501..9043cf4 100644
--- a/CHANGELOG
+++ b/CHANGELOG
@@ -2,6 +2,14 @@
Below is a complete listing of changes for each revision of HighLine.
+== 1.6.3
+
+* Provisional update by Richard LeBer
+* Add colors NONE and DEFAULT
+* Add RGB color capability
+* Add HighLine::String class with convenience methods: #color (alias #foreground, #in), #on (alias #background), colors, and styles
+* Add (optional) ability to extend String with the same convenience methods from HighLine::String
+
== 1.6.2
* Correctly handle STDIN being closed before we receive any data (fix by
diff --git a/lib/highline.rb b/lib/highline.rb
index 20d59d2..aa1ded4 100644
--- a/lib/highline.rb
+++ b/lib/highline.rb
@@ -29,7 +29,7 @@ require "highline/color_scheme"
#
class HighLine
# The version of the installed library.
- VERSION = "1.6.2".freeze
+ VERSION = "1.6.3".freeze
# An internal HighLine error. User code does not need to trap this.
class QuestionError < StandardError
@@ -120,8 +120,13 @@ class HighLine
MAGENTA = "\e[35m"
# Set the terminal's foreground ANSI color to cyan.
CYAN = "\e[36m"
# Set the terminal's foreground ANSI color to white.
WHITE = "\e[37m"
+ GRAY = WHITE
+ # Set the terminal's foreground ANSI color to none (on Mac OSX Terminal, this is bright white)
+ NONE = "\e[38m"
+ # Set the terminal's foreground ANSI color to default (Has no effect, but used with RGB colors)
+ DEFAULT = "\e[39m"
# Set the terminal's background ANSI color to black.
ON_BLACK = "\e[40m"
@@ -120,8 +120,13 @@ class HighLine
# Set the terminal's foreground ANSI color to cyan.
CYAN = "\e[36m"
- # Set the terminal's foreground ANSI color to white.
+ # Set the terminal's foreground ANSI color to white (on Mac OSX Terminal, this is actually gray).
WHITE = "\e[37m"